#### Phonetic borrowings (1+2) ANALYSES OF MCUs WITH LINEAR MIXED EFFECTS MODELS ####

#### Brife Introduction ####

#The script was originally run with R version 3.5.3 and R Studio version 1.2.1335.

# This code for the experiment regarding processing of phonetic borrowings (1+2) in Chinese reading.

# We did target word analyses. Our target words were 3-character phonetic borrowing/loan words. 

# TARGET WORD ANALYSES 
# N1 = the first character of a 3-character loan word.
# N2 = the second and the third characters of a 3-chararcter loan word.
# This was a 2(N1:identity VS.Pseudocharacter) x 2(N2:identity VS.Pseudocharacter) experiment design.

# Interest areas
# N+1 = the first character of a 3-character loan word.
# N+2 = the second and the third characters of a 3-chararcter loan word.
# Whole = 3 characters of the name(whole loan word) 

#    Following the procedure we used to trim the random structure of the models in case of convergence failure.
#    We started trimming the random structure for stims, starting with removal of the random effect correlations, then the random slopes.
#    1+A*B|participant               1+A*B|stim          #Full model with slope and intercept
#    1+A*B|participant               0+A*B|stim          #Remove correlations of item
#    1+A*B|participant               1+A+B|stim          #Remove interactions (with correlation back in) of item
#    1+A*B|participant               0+A+B|stim          #Remove correlation and interactions of item
#    1+A*B|participant               1+A|stim            #Remove one of the slopes
#    1+A*B|participant               1+B|stim            #Remove the other one of the slopes
#    1+A*B|participant               1|stim+0+A|stim     #Again without one correlation for stim
#    1+A*B|participant               1|stim+0+B|stim     #Again without the other correlation for stim
#    1+A*B|participant               1|stim              #Remove the slope for stim
#    0+A*B|participant               1|stim              #Remove correlation for participant
#    1+A+B|participant               1|stim              #Remove interaction (but with correlation back in) for participant
#    0+A+B|participant               1|stim              #Remove interaction and correlation for participant
#    1+B|participant                 1|stim              #Remove one slope for participant
#    1+A|participant                 1|stim              #Remove the other one slope for participant
#    1|participant+0+A|participant   1|stim              #Again without correlation for participant
#    1|participant+0+B|participant   1|stim              #Again without the other correlation for participant
#    1|participant                   1|stim              #Leave only the intercept

#    Then, we analyzed the Simple effect for the interactions.
#    We started trimming with removal of random slop of item, then remove the slop of participant.
#    1+condition|participant         1+condition|stim    #Full model
#    1+condition|participant         1|stim              #Remove the slop of stim
#    1|participant                   1|stim              #Remove the slop of participant
#    1|participant                                       #Remove the random stim variable 

# There are mainly two parts for brand name analyses.
# Part1 The code for continuous variables in target word analyses(FFD,SFD,GD,TFD,Go_past)
# Part2 The code for skipping and regression_out in target word analyses.
# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.
# Create a folder which contains all .csv files for target analyses.

#### Libraries needed to run the current R code ####
library(languageR)#version 1.5.0
library(lme4)     #version 1.1-19
library(lattice)  #version 0.20-40
library(lmerTest) #if you want p values for your lmer model #version 3.1-0
library(MASS)     #version 7.3-51.5
library(plyr)     #version 1.8.4
library(yarrr)    #version 0.1.5

#### Clean up ####
rm(list=ls())

#### Part1-TARGET WORDS ANALYSES-Continuous dependent variables####

# 1.Load data
# open the csv.file according to data name.
datafile = read.csv("N+1_FFD.csv", header=TRUE,sep = ",",dec=".") 
# 2215 observations for N+1_FFD
# 2115 observations for N+1_SFD
# 2203 observations for N+1_GD
# 2205 observations for N+1_TFD
# 2194 observations for N+1_Go_past

# 4033 observations for N+2_FFD
# 3364 observations for N+2_SFD
# 4031 observations for N+2_GD
# 4445 observations for N+2_TFD
# 3999 observations for N+2_Go_past

# 4845 observations for Whole_FFD
# 2717 observations for Whole_SFD
# 4839 observations for Whole_GD
# 5109 observations for Whole_TFD
# 4810 observations for Whole_Go_past

head(datafile) # generally check the file you have imported
measure = "FFD" # choose dependent variable
datafile$depvar = datafile[,measure] # add to dataframe

# 2.Set up variables 
colnames(datafile) #checked the column names
col.subject = 1    #specify which column your participant number is in, participant
col.stim = 2    #specify which column your stim number is in, trial
col.n1 =6 #specify which column N1 number is
col.n2 =7 #specify which column  N2 number is
col.condition =3 #specify which column conditon number is
head(datafile)

#### Part1-TARGET WORDS ANALYSES-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$stim = datafile[,col.stim]

#### Part1-TARGET WORDS ANALYSES-Make sure all variables are correct class ####
str(datafile)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$n2 = as.factor(datafile$n2)
datafile$n1 = as.factor(datafile$n1)
datafile$condition = as.factor(datafile$condition)
datafile$depvar = as.numeric(datafile$depvar)

#### Part1-TARGET WORDS ANALYSES-Remove outlier ####
# Remove data outside 3 standard deviations
head(datafile) #let's first have a look
nrcolumns = ncol(datafile)   
# make a new datafile with eye movement measures > 0
between1 = datafile[datafile$depvar > 0, ]
head(between1)
between1 = datafile
#make a matrix with the means per subject for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp ), sd, na.rm = T)
sd.matrix
# add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
# make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]
# you might want to clean up this data file by removing the added columns
result = result[,1:nrcolumns]
tussen1 = result# insert the name from the datafile coming from the clean up on the right
nrow(datafile)-nrow(tussen1) # calculate how many row you removed
# calculate how many row rate
rate=(nrow(datafile)-nrow(tussen1))/nrow(datafile) 
rate 
datafile = tussen1 
nrow(datafile)# checked the observations after remove outlier

#### Part1-TARGET WORD ANALYSES-Means,Standard Deviations and Standard Errors####
##Code for calculating means between per pp and per condition
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt
## then calculate the grand mean by condition
grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.tt, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(80)  ## this number is the total number of participants from your data, so it is changable.
grand.se
# Paste the results into .txt file

#### Part1-TARGET WORD ANALYSES-Data visualization ####
# Do we need to transform?
#NOTICE:MLP, MLP_single and MLP_multiple can not log transform because the existance of 0.
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log transform data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar) 
# 3.checked the distrubition for every participant
qqmath(~depvar|RECORDING_SESSION_LABEL, data = datafile)

####Part1-TARGET ANALYSES-Linear Mixed Models (LMM)####
# 1.Check the levels of N1 and N2.
levels(datafile$ n1)
levels(datafile$ n2)

# 2.Do the contrast.
contrasts(datafile$ n1) <- contr.sdif(2)
contrasts(datafile$ n2) <- contr.sdif(2)

# 3.Run linear mixed-effects models (LMM)
# 1.Full model
depvar.lmer1 = lmer(depvar ~ n1 *  n2 + (1 + n1 *  n2|pp) + (1 + n1 *  n2|stim), datafile)
summary(depvar.lmer1, corr = FALSE)
# 2.Remove correlations of item
depvar.lmer2 = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (0 + n1 *  n2|stim), datafile)
summary(depvar.lmer2, corr = FALSE)
# 3.remove interactions (with correlation back in) of item
depvar.lmer3 = lmer(depvar ~ n1 *  n2   + (1 + n1 *  n2|pp) + (1 + n1 +  n2|stim), datafile)
summary(depvar.lmer3, corr = FALSE)
# 4. Remove correlation and interactions of item
depvar.lmer4 = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (0 + n1 +  n2|stim), datafile)
summary(depvar.lmer4, corr = FALSE)
# 5a. remove one of the slopes
depvar.lmer5a = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (1 + n1|stim), datafile)
summary(depvar.lmer5a, corr = FALSE)
# 5b.
depvar.lmer5b = lmer(depvar ~ n1 *  n2+ (1 + n1 *  n2|pp) + (1 +  n2|stim), datafile)
summary(depvar.lmer5b, corr = FALSE)
# 6a. Again, without correlation
depvar.lmer6a = lmer(depvar ~ n1 *  n2+ (1 + n1 *  n2|pp) + (1|stim) + (0 + n1|stim), datafile)
summary(depvar.lmer6a, corr = FALSE)
# 6b.
depvar.lmer6b = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (1|stim) + (0 +  n2|stim), datafile)
summary(depvar.lmer6b, corr = FALSE)
# 7. Intercept only for items
depvar.lmer7 = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (1|stim), datafile)
summary(depvar.lmer7, corr = FALSE)
# 8. Remove correlation for pp
depvar.lmer8 = lmer(depvar ~ n1 *  n2  + (0 + n1 *  n2|pp) + (1|stim), datafile)
summary(depvar.lmer8, corr = FALSE)
# 9. Remove interaction (but with correlation back in) for pp
depvar.lmer9 = lmer(depvar ~ n1 * n2  + (1 + n1 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer9, corr = FALSE)
# 10. Remove interaction and correlation for pp
depvar.lmer10 = lmer(depvar ~ n1 *  n2  + (0 + n1 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer10, corr = FALSE)
# 11a. Remove one slope for pp
depvar.lmer11a = lmer(depvar ~ n1 *  n2  + (1 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer11a, corr = FALSE)
# 11b.
depvar.lmer11b = lmer(depvar ~ n1 *  n2  + (1 + n1|pp) + (1|stim), datafile)
summary(depvar.lmer11b, corr = FALSE)
# 12a. Again without correlation for pp
depvar.lmer12a = lmer(depvar ~ n1 *  n2  + (1|pp) + (0 + n1|pp) + (1|stim), datafile)
summary(depvar.lmer12a, corr = FALSE)
# 12b.
depvar.lmer12b = lmer(depvar ~ n1 *  n2  + (1|pp) + (0 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer12b, corr = FALSE)
# 13. Intercepts only 
depvar.lmer13 = lmer(depvar ~ n1 *  n2  + (1|pp) + (1|stim), datafile)
summary(depvar.lmer13, corr = FALSE)

# FFD, TFD run depvar.lmer13
# SFD, GD, Go_past run depvar.lmer11a
# Paste the results into .txt file

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(depvar.lmer1, method="Wald") # calculate CI of the model you run.
# Paste the results into .txt file

#### Part1-Simple effect analysis for the interactions ####
##1.1 vs 2: N+1 preview benefits??3 vs 4: if there was a N+2 preview benefit when the N+1 was a pseudocharacter.
levels(datafile$condition)
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,
                                                    0,0,-0.5,+0.5)  
                                                  ,4,2),2)        
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
contrast2.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp), data = datafile)
summary(contrast3.lmer, corr = FALSE)

# FFD, SFD, GD, Go_past, TFD run contrast3.

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(contrast3.lmer, method="Wald") # calculate CI of the model you run.

#2.1 VS 3: if where was a n+1 preview benefit when n+2 was an identity; 2 VS 4: if where was a n+1 preview benefit when n+2 was a pseudocharacter.
datafile$condition <- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,
                                                    0,-0.5,0,+0.5)  
                                                  ,4,2),2)          

# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
contrast2.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

# FFD, SFD, GD, TFD run contrast3.
# Go_past run contrast2.

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(contrast3.lmer, method="Wald") # calculate CI of the model you run.

#### Clean up and notice####
rm(list=ls())
#NOTICE: The code for FFD,SFD,GD,TFD,Go_past are same.



####Part2-TARGET WORD ANALYSES-Skiping & REGRESSION_OUT. ####

# 1.Load data
datafile = read.csv("N+1_SKIP.csv", header=TRUE,sep = ",",dec=".") 
# 2233 observations for N+1_Regression_out
# 5283 observations for N+1_skipping

# 4083 observations for N+2_Regression_out
# 5283 observations for N+2_skipping

# 4900 observations for whole_Regression_out
# 5278 observations for whole_skipping

head(datafile) #generally check the file you have imported
measure = "IA_SKIP" # choose dependent variable
datafile$depvar = datafile[,measure] # add to dataframe

# 2.Set up variables 

colnames(datafile) #checked the column names
col.subject = 1    #specify which column your participant number is in, participant
col.stim = 2    #specify which column your stim number is in, trial
col.n1 =6 #specify which column N1 number is
col.n2 =7 #specify which column  N2 number is
col.condition =3 #specify which column conditon number is
head(datafile)

#### Part1-TARGET WORDS ANALYSES-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$stim = datafile[,col.stim]

#### Part1-TARGET WORDS ANALYSES-Make sure all variables are correct class ####
str(datafile)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$n2 = as.factor(datafile$n2)
datafile$n1 = as.factor(datafile$n1)
datafile$condition = as.factor(datafile$condition)
datafile$depvar = as.numeric(datafile$depvar)

#### Part2-TARGET WORDS ANALYSES-Means,Standard Deviations and Standard Errors####
#Make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
#Make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
## Calculate the grand mean, grand SD, and grand SE by condition
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(80)  ##The number of the participants is 80. 
grand.se
# Paste the results into .txt file

#### Part2-TARGET WORDS ANALYSES-Models####

# 1.Check the levels of N1 and N2.
levels(datafile$ n1)
levels(datafile$ n2)

# 2.Do the contrast.
contrasts(datafile$ n1) <- contr.sdif(2)
contrasts(datafile$ n2) <- contr.sdif(2)

# 1. Full model
depvar.lmer1 = glmer(depvar ~ n1 *n2   + (1 + n1 *n2|pp) + (1 + n1 *n2|stim), datafile, family = binomial)
summary(depvar.lmer1, corr = FALSE)
# 2. remove correlations of item
depvar.lmer2 = glmer(depvar ~ n1 *n2 + (1 + n1 *n2|pp) + (0 + n1 *n2|stim), datafile, family = binomial)
summary(depvar.lmer2, corr = FALSE)
# 3. remove interactions (with correlation back in) of item
depvar.lmer3 = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1 + n1 +n2|stim), datafile, family = binomial)
summary(depvar.lmer3, corr = FALSE)
# 4. Remove correlation and interactions of item
depvar.lmer4 = glmer(depvar ~ n1 *n2 + (1 + n1 *n2|pp) + (0 + n1 +n2|stim), datafile, family = binomial)
summary(depvar.lmer4, corr = FALSE)
# 5a. remove one of the slopes 
depvar.lmer5a = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1 + n1|stim), datafile, family = binomial)
summary(depvar.lmer5a, corr = FALSE)
#5b. 
depvar.lmer5b = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1 +n2|stim), datafile, family = binomial)
summary(depvar.lmer5b, corr = FALSE)
# 6a. Again, without correlation
depvar.lmer6a = glmer(depvar ~ n1 * n2+ (1 + n1 *n2|pp) + (1|stim) + (0 + n1|stim), datafile, family = binomial)
summary(depvar.lmer6a, corr = FALSE)
# 6b.
depvar.lmer6b = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1|stim) + (0 +n2|stim), datafile, family = binomial)
summary(depvar.lmer6b, corr = FALSE)
# 7. Intercept only for items
depvar.lmer7 = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer7, corr = FALSE)
# 8. Remove correlation for pp
depvar.lmer8 = glmer(depvar ~ n1 *n2   + (0 + n1 *n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer8, corr = FALSE)
# 9. Remove interaction (but with correlation back in) for pp
depvar.lmer9 = glmer(depvar ~ n1 *n2 + (1 + n1 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer9, corr = FALSE)
# 10. Remove interaction and correlation for pp
depvar.lmer10 = glmer(depvar ~ n1 *n2 + (0 + n1 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer10, corr = FALSE)
# 11a. Remove one slope for pp
depvar.lmer11a = glmer(depvar ~ n1 *n2  + (1 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11a, corr = FALSE)
# 11b.
depvar.lmer11b = glmer(depvar ~ n1 *n2 + (1 + n1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11b, corr = FALSE)
# 12a. Again without correlation for pp
depvar.lmer12a = glmer(depvar ~ n1 *n2  + (1|pp) + (0 + n1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12a, corr = FALSE)
# 12b.
depvar.lmer12b = glmer(depvar ~ n1 *n2  + (1|pp) + (0 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12b, corr = FALSE)
# 13. Intercepts only
depvar.lmer13 = glmer(depvar ~ n1 *n2 + (1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

# skipping run glmer13
# Regression_out run glmer11b
# Paste the results into .txt file

####Part2-TARGET WORD ANALYSES- Confidence interval####
confint(depvar.glmer4, method="Wald")
# Paste the results into .txt file

#### Part2-Simple effect analysis for the interactions ####
##1.1 vs 2: N+1 preview benefits??3 vs 4: if there was a N+2 preview benefit when the N+1 was a pseudocharacter.
levels(datafile$condition)
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,
                                                    0,0,-0.5,+0.5)  
                                                  ,4,2),2)        

# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
contrast1.glmer <- glmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), datafile, family = binomial)
summary(contrast1.glmer, corr = FALSE)
contrast2.glmer <- glmer(depvar ~ condition  + (1+condition|pp) + (1|stim), datafile, family = binomial)
summary(contrast2.glmer, corr = FALSE)
contrast3.glmer <- glmer(depvar ~ condition  + (1|pp) + (1|stim), datafile, family = binomial)
summary(contrast3.glmer, corr = FALSE)
contrast4.glmer <- glmer(depvar ~ condition  + (1|pp) , datafile, family = binomial)
summary(contrast4.glmer, corr = FALSE)

####Part2-TARGET WORD ANALYSES- Confidence interval####
confint(contrast3.glmer, method="Wald")

#2.1 VS 3: if where was a n+1 preview benefit when n+2 was an identity; 2 VS 4: if where was a n+1 preview benefit when n+2 was a pseudocharacter.
datafile$condition <- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,
                                                    0,-0.5,0,+0.5)  
                                                  ,4,2),2)          
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
contrast1.glmer <- glmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), datafile, family = binomial)
summary(contrast1.glmer, corr = FALSE)
contrast2.glmer <- glmer(depvar ~ condition  + (1+condition|pp) + (1|stim), datafile, family = binomial)
summary(contrast2.glmer, corr = FALSE)
contrast3.glmer <- glmer(depvar ~ condition  + (1|pp) + (1|stim), datafile, family = binomial)
summary(contrast3.glmer, corr = FALSE)
contrast4.glmer <- glmer(depvar ~ condition  + (1|pp) , datafile, family = binomial)
summary(contrast4.glmer, corr = FALSE)

####Part2-TARGET WORD ANALYSES- Confidence interval####
confint(contrast3.glmer, method="Wald")

####Part2-clean up and notice####
rm(list=ls())
#NOTICE: The code for SKIP and REGRESSION_OUT are same.

###End###